@@ -173,38 +173,38 @@ QUERY_COMMANDS = {
                 "V",
                 {"icon": "mdi:transmission-tower-export"},
             ],
-            [2, "AC Input Frequency", "float", "Hz", {"icon": "mdi:current-ac"}],
-            [3, "AC Output Voltage", "float", "V", {"icon": "mdi:power-plug"}],
-            [4, "AC Output Frequency", "float", "Hz", {"icon": "mdi:current-ac"}],
+            [2, "AC Input Frequency", "float", "Hz", {"icon": "mdi:current-ac", "device-class": "frequency"}],
+            [3, "AC Output Voltage", "float", "V", {"icon": "mdi:power-plug", "device-class": "voltage"}],
+            [4, "AC Output Frequency", "float", "Hz", {"icon": "mdi:current-ac", "device-class": "frequency"}],
             [5, "AC Output Apparent Power", "int", "VA", {"icon": "mdi:power-plug", "device-class": "apparent_power"}],
-            [6, "AC Output Active Power", "int", "W", {"icon": "mdi:power-plug"}],
+            [6, "AC Output Active Power", "int", "W", {"icon": "mdi:power-plug", "device-class": "power"}],
             [7, "AC Output Load", "int", "%", {"icon": "mdi:brightness-percent"}],
-            [8, "BUS Voltage", "int", "V", {"icon": "mdi:details"}],
-            [9, "Battery Voltage", "float", "V", {"icon": "mdi:battery-outline"}],
-            [10, "Battery Charging Current", "int", "A", {"icon": "mdi:current-dc"}],
+            [8, "BUS Voltage", "int", "V", {"icon": "mdi:details", "device-class": "voltage"}],
+            [9, "Battery Voltage", "float", "V", {"icon": "mdi:battery-outline", "device-class": "voltage"}],
+            [10, "Battery Charging Current", "int", "A", {"icon": "mdi:current-dc", "device-class": "current"}],
             [11, "Battery Capacity", "int", "%", {"device-class": "battery"}],
             [
                 12,
                 "Inverter Heat Sink Temperature",
                 "int",
                 "°C",
-                {"icon": "mdi:details"},
+                {"icon": "mdi:details", "device-class": "temperature"},
             ],
-            [13, "PV1 Input Current", "float", "A", {"icon": "mdi:solar-power"}],
-            [14, "PV1 Input Voltage", "float", "V", {"icon": "mdi:solar-power"}],
+            [13, "PV1 Input Current", "float", "A", {"icon": "mdi:solar-power", "device-class": "current"}],
+            [14, "PV1 Input Voltage", "float", "V", {"icon": "mdi:solar-power", "device-class": "voltage"}],
             [
                 15,
                 "Battery Voltage from SCC",
                 "float",
                 "V",
-                {"icon": "mdi:battery-outline"},
+                {"icon": "mdi:battery-outline", "device-class": "voltage"},
             ],
             [
                 16,
                 "Battery Discharge Current",
                 "int",
                 "A",
-                {"icon": "mdi:battery-negative"},
+                {"icon": "mdi:battery-negative", "device-class": "current"},
             ],
             [
                 17,
@@ -223,7 +223,7 @@ QUERY_COMMANDS = {
             ],
             [18, "Battery Voltage Offset for Fans On", "int", "10mV"],
             [19, "EEPROM Version", "int", ""],
-            [20, "PV1 Charging Power", "int", "W", {"icon": "mdi:solar-power"}],
+            [20, "PV1 Charging Power", "int", "W", {"icon": "mdi:solar-power", "device-class": "power"}],
             [
                 21,
                 "Device Status2",
@@ -253,9 +253,9 @@ QUERY_COMMANDS = {
         "type": "QUERY",
         "response_type": "INDEXED",
         "response": [
-            [1, "PV2 Input Current", "float", "A", {"icon": "mdi:solar-power"}],
-            [2, "PV2 Input Voltage", "float", "V", {"icon": "mdi:solar-power"}],
-            [3, "PV2 Charging Power", "int", "W", {"icon": "mdi:solar-power"}],
+            [1, "PV2 Input Current", "float", "A", {"icon": "mdi:solar-power", "device-class": "current"}],
+            [2, "PV2 Input Voltage", "float", "V", {"icon": "mdi:solar-power", "device-class": "voltage"}],
+            [3, "PV2 Charging Power", "int", "W", {"icon": "mdi:solar-power", "device-class": "power"}],
         ],
         "test_responses": [
             b"(03.1 327.3 01026 \xc9\x8b\r",
@@ -323,32 +323,32 @@ QUERY_COMMANDS = {
                     "86": "AC output mode setting different",
                 },
             ],
-            [5, "Grid Voltage", "float", "V", {"icon": "mdi:power-plug"}],
-            [6, "Grid Frequency", "float", "Hz", {"icon": "mdi:current-ac"}],
-            [7, "AC Output Voltage", "float", "V", {"icon": "mdi:power-plug"}],
-            [8, "AC Output Frequency", "float", "Hz", {"icon": "mdi:current-ac"}],
+            [5, "Grid Voltage", "float", "V", {"icon": "mdi:power-plug", "device-class": "voltage"}],
+            [6, "Grid Frequency", "float", "Hz", {"icon": "mdi:current-ac", "device-class": "frequency"}],
+            [7, "AC Output Voltage", "float", "V", {"icon": "mdi:power-plug", "device-class": "voltage"}],
+            [8, "AC Output Frequency", "float", "Hz", {"icon": "mdi:current-ac", "device-class": "frequency"}],
             [9, "AC Output Apparent Power", "int", "VA", {"icon": "mdi:power-plug", "device-class": "apparent_power"}],
-            [10, "AC Output Active Power", "int", "W", {"icon": "mdi:power-plug"}],
+            [10, "AC Output Active Power", "int", "W", {"icon": "mdi:power-plug", "device-class": "power"}],
             [11, "Load Percentage", "int", "%", {"icon": "mdi:brightness-percent"}],
-            [12, "Battery Voltage", "float", "V", {"icon": "mdi:battery-outline"}],
-            [13, "Battery Charging Current", "int", "A", {"icon": "mdi:current-dc"}],
+            [12, "Battery Voltage", "float", "V", {"icon": "mdi:battery-outline", "device-class": "voltage"}],
+            [13, "Battery Charging Current", "int", "A", {"icon": "mdi:current-dc", "device-class": "current"}],
             [14, "Battery Capacity", "int", "%", {"device-class": "battery"}],
-            [15, "PV1 Input Voltage", "float", "V", {"icon": "mdi:solar-power"}],
+            [15, "PV1 Input Voltage", "float", "V", {"icon": "mdi:solar-power", "device-class": "voltage"}],
             [
                 16,
                 "Total Charging Current",
                 "int",
                 "A",
-                {"icon": "mdi:brightness-percent"},
+                {"icon": "mdi:brightness-percent", "device-class": "current"},
             ],
             [
                 17,
                 "Total AC Output Apparent Power",
                 "int",
                 "VA",
-                {"icon": "mdi:power-plug"},
+                {"icon": "mdi:power-plug", "device-class": "apparent_power"},
             ],
-            [18, "Total Output Active Power", "int", "W", {"icon": "mdi:power-plug"}],
+            [18, "Total Output Active Power", "int", "W", {"icon": "mdi:power-plug", "device-class": "power"}],
             [
                 19,
                 "Total AC Output Percentage",
@@ -393,19 +393,19 @@ QUERY_COMMANDS = {
                 "option",
                 ["Utility first", "Solar first", "Solar + Utility", "Solar only"],
             ],
-            [23, "Max Charger Current", "int", "A"],
-            [24, "Max Charger Range", "int", "A"],
-            [25, "Max AC Charger Current", "int", "A"],
-            [26, "PV1 Input Current", "int", "A", {"icon": "mdi:solar-power"}],
+            [23, "Max Charger Current", "int", "A", {"device-class": "current"}],
+            [24, "Max Charger Range", "int", "A", {"device-class": "current"}],
+            [25, "Max AC Charger Current", "int", "A", {"device-class": "current"}],
+            [26, "PV1 Input Current", "int", "A", {"icon": "mdi:solar-power", "device-class": "power"}],
             [
                 27,
                 "Battery Discharge Current",
                 "int",
                 "A",
-                {"icon": "mdi:battery-negative"},
+                {"icon": "mdi:battery-negative", "device-class": "current"},
             ],
-            [28, "PV2 Input Voltage", "float", "V", {"icon": "mdi:solar-power"}],
-            [29, "PV2 Input Current", "int", "A", {"icon": "mdi:solar-power"}],
+            [28, "PV2 Input Voltage", "float", "V", {"icon": "mdi:solar-power", "device-class": "voltage"}],
+            [29, "PV2 Input Current", "int", "A", {"icon": "mdi:solar-power", "device-class": "current"}],
         ],
         "test_responses": [
             b"(0 92932105105315 B 00 000.0 00.00 230.0 50.00 0989 0907 012 53.2 009 090 349.8 009 00989 00907 011 10100110 0 1 100 120 030 02 000 275.3 02i]\r",
@@ -816,12 +816,12 @@ QUERY_COMMANDS = {
         "description": "Daily PV Generated Energy Inquiry",
         "help": " -- display daily generated energy, format is QEDyyyymmdd",
         "type": "QUERY",
-        "response_type": "SEQUENTIAL",
+        "response_type": "INDEXED",
         "response": [
-            ["int", "PV Generated Energy for Day", "Wh"],
-            ["info:cv[:4]", "Year", ""],
-            ["info:calendar.month_name[int(cv[4:6])]", "Month", ""],
-            ["info:cv[6:]", "Day", ""],
+            [1, "PV Generated Energy for Day", "int", "Wh", {"icon": "mdi:solar-power", "device-class": "power"}],
+            [2, "Year", "info:cv[:4]", ""],
+            [3, "Month", "info:calendar.month_name[int(cv[4:6])]", ""],
+            [4, "Day", "info:cv[6:]", ""],
         ],
         "test_responses": [
             b"(00238800!J\r",
